Concept Predictors
=======================

This module provides predictor implementations that map from concepts to target predictions.

.. currentmodule:: torch_concepts.nn

Summary
-------

**Predictor Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   LinearCC
   MixCUC
   HyperLinearCUC
   CallableCC


Class Documentation
-------------------

.. autoclass:: LinearCC
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: MixCUC
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: HyperLinearCUC
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: CallableCC
   :members:
   :undoc-members:
   :show-inheritance:
